@@ -26,6 +26,7 @@ from QWeb.internal import element, javascript, frame, util, browser
 from QWeb.internal.exceptions import QWebElementNotFoundError, QWebValueError,\
     QWebInstanceDoesNotExistError, QWebStalingElementError
 from QWeb.internal.config_defaults import CONFIG
+from QWeb.internal.search_strategy import SearchStrategies
 
 
 def get_element_by_locator_text(locator: str,
@@ -93,10 +94,11 @@ def get_text_elements(text: str, **kwargs) -> Optional[list[WebElement]]:
     shadow_dom = CONFIG['ShadowDOM']
     if shadow_dom:
         shadow_elements = get_texts_including_shadow_dom(text, partial, **kwargs)
-        #  remove duplicates (normal search and including shadow search)
-        for el in shadow_elements:
-            if web_elements is not None and el not in list(web_elements):
-                web_elements.append(el)  # type: ignore[union-attr]
+        # remove possible stale elements
+        web_elements = util.remove_stale_elements(web_elements)  # type: ignore
+        # remove duplicates
+        web_elements = util.remove_duplicates_from_list(shadow_elements,
+                                                        web_elements)  # type: ignore
     return web_elements
 
 
@@ -146,19 +148,22 @@ def check_all_nodes(text: str, **kwargs) -> Optional[list[WebElement]]:
 def get_all_text_elements(text: str, **kwargs) -> list[WebElement]:
     """Get all webelements found by text"""
     web_elements: list[WebElement] = []
+    shadow_dom = CONFIG['ShadowDOM']
     all_text_nodes = util.par2bool(kwargs.get('all_text_nodes', CONFIG['AllTextNodes']))
     kwargs['partial_match'] = kwargs.get('partial_match', CONFIG['PartialMatch'])
     if all_text_nodes:
         web_elements = check_all_nodes(text, **kwargs)
         if web_elements:
             return web_elements
+
     if 'css' not in kwargs:
         try:
-            web_elements = get_clickable_element_by_js(text, **kwargs)
+            web_elements = get_clickable_element_by_js(text, shadow_dom=shadow_dom, **kwargs)
         except (JavascriptException, WebDriverException, NoSuchFrameException,
                 QWebStalingElementError) as e:
             logger.debug('got {}. Syntax might be invalid'.format(e))
     if not web_elements:
+        # shadow dom search for all texts is done inside get_text_elements
         web_elements = get_text_elements(text, **kwargs)  # type: ignore[assignment]
     if not web_elements:
         raise QWebElementNotFoundError('Webpage did not contain text "{}"'.format(text))
@@ -190,18 +195,11 @@ def get_text_using_anchor(text: str, anchor: str, **kwargs) -> WebElement:
     WebElement
     """
     web_elements = get_all_text_elements(text, **kwargs)
-    modal_xpath = CONFIG['IsModalXpath']
 
-    driver = browser.get_current_browser()
-    if modal_xpath != "//body":
-        # filter elements by modal (dialog etc)
-        logger.debug("IsModalXpath filtering on, filtering...")
-        modal_exists = driver.find_elements(By.XPATH, modal_xpath)
-        if modal_exists:
-            web_elements = _filter_by_modal_ancestor(web_elements)
-            logger.debug(f"after filtering there are: {len(web_elements)} matching elements")
-            if not web_elements:
-                raise QWebElementNotFoundError('Webpage did not contain text "{}"'.format(text))
+    # filter elements by modal (dialog etc) if needed
+    web_elements = filter_by_modal_ancestor(web_elements)
+    if not web_elements:
+        raise QWebElementNotFoundError('Webpage did not contain text "{}"'.format(text))
 
     if len(web_elements) == 1:
         return web_elements[0]
@@ -220,11 +218,26 @@ def _get_contains_text_element(text: str, **kwargs) -> list[WebElement]:
     return element.get_webelements_in_active_area(xpath, **kwargs)
 
 
-def _filter_by_modal_ancestor(elements: list[WebElement]) -> list[WebElement]:
+def filter_by_modal_ancestor(elements: list[WebElement]) -> list[WebElement]:
     xpath = CONFIG["IsModalXpath"]
+    if xpath.startswith("xpath="):
+        xpath = xpath.split("=", 1)[1]
     if xpath.startswith("//"):
         xpath = xpath[2:]
 
+    modal_xpath = CONFIG['IsModalXpath']
+    driver = browser.get_current_browser()
+    # no filtering if modal setting is the default one
+    if modal_xpath == SearchStrategies.IS_MODAL_XPATH:
+        return elements
+
+    # filter elements by modal (dialog etc)
+    logger.debug("IsModalXpath filtering on, filtering...")
+    modal_exists = driver.find_elements(By.XPATH, modal_xpath)
+    # no filtering if modal element doesn't exist
+    if not modal_exists:
+        return elements
+
     logger.debug(f"length before filtering: {len(elements)}")
     elems_in_modal = []
 
@@ -285,6 +298,8 @@ def get_element_using_anchor(elements: list[WebElement], anchor: Optional[Union[
                 if len(anchor_elements) > 0:
                     logger.debug('No exact match found, using first partial match')
                     anchor_element = anchor_elements[0]
+                else:
+                    raise QWebElementNotFoundError(f"Could not find elements for anchor: {anchor}")
         else:
             anchor_element = get_unique_text_element(anchor, **kwargs)
         return element.get_closest_element(anchor_element, elements)
@@ -348,9 +363,16 @@ def _get_item_by_css(text: str, **kwargs) -> Optional[list[WebElement]]:
 
 
 @frame.all_frames
-def get_clickable_element_by_js(locator: str, **kwargs) -> Optional[list[WebElement]]:
-    web_elements = element.get_visible_elements_from_elements(javascript.get_clickable(locator),
-                                                              **kwargs)
+def get_clickable_element_by_js(locator: str,
+                                shadow_dom: bool = False,
+                                **kwargs) -> Optional[list[WebElement]]:
+    partial = kwargs['partial_match']
+    if shadow_dom:
+        web_elements = element.get_visible_elements_from_elements(
+                       javascript.get_clickable_from_shadow_dom(locator, partial))
+    else:
+        web_elements = element.get_visible_elements_from_elements(javascript.get_clickable(
+                                                                  locator), **kwargs)
     if web_elements:
         logger.debug('Found elements by js: {}'.format(web_elements))
         return web_elements
