@@ -57,11 +57,6 @@ def return_browser() -> WebDriver:
 def open_browser(url: str, browser_alias: str, options: Optional[str] = None, **kwargs):
     r"""Open new browser to given url.
 
-    Uses the Selenium2Library open_browser method if the browser is not Chrome.
-
-    For Chrome, recognizes if we are inside docker container and sets chrome
-    capabilities accordingly.
-
     Browser options can also be given in the robot command, for example:
     robot -v browser_options:"--kiosk, --disable-gpu" testytest.robot
 
@@ -83,7 +78,37 @@ def open_browser(url: str, browser_alias: str, options: Optional[str] = None, **
         #Supply preferences from a dictionary
         ${prefs_d}=    Create Dictionary     option1    value1    option2    value2
         OpenBrowser    http://google.com     firefox    prefs=${prefs_d}
+        #Mobile emulation
+        OpenBrowser    http://google.com     chrome    emulation=iPhone SE
+        OpenBrowser    http://google.com     chrome    emulation=375x812
 
+    Mobile emulation
+    ----------------
+    Giving a valid device profile or screen dimensions in "emulation" argument turns on
+    "mobile emulation".
+
+    Supported browsers: desktop Chrome and Edge only.
+
+    See examples above. Always make sure the device profile name exists. You can either define
+    a new one or use one of the default profiles:
+
+        * iPhone SE
+        * iPhone XR
+        * iPhone 12 Pro
+        * Pixel 5
+        * Samsung Galaxy S8+
+        * Samsung Galaxy S20 Ultra
+        * iPad Air
+        * iPad Mini
+        * Surface Pro 7
+        * Surface Duo
+        * Galaxy Fold
+        * Samsung Glazy A51/71
+        * Nest Hub
+        * Nest Hub Max
+
+    Note that profile names given above are expected to change in new browser releases.
+    Always check that the name you are using still exists.
 
     Experimental feature for test debugging (for Chrome only):
     ----------------------------------------------------------
@@ -124,7 +149,15 @@ def open_browser(url: str, browser_alias: str, options: Optional[str] = None, **
         Arguments for initialization of WebDriver objects(chrome).
         Some available opts: https://peter.sh/experiments/chromium-command-line-switches/
     kwargs
-        prefs=args: Experimental options for chrome browser.
+        prefs=args:
+            Experimental options for chrome browser.
+        emulation:
+            Turns on "mobile emulation" in desktop browser. Useful for testing websites
+            simulating a mobile device screen dimensions.
+            Supported browsers: desktop Chrome and Edge only.
+            Existing device profile name (i.e. "iPhone SE", must exist)
+            OR device dimensions in format:
+            WIDTHxHEIGHT (i.e. 385x812)
 
     Raises
     ------
